@@ -338,7 +338,10 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                             )
                         ] = self.w_axis_1.axis_selected
             else:
-                if self.w_axis_1.axis_selected in ifft_dict:
+                if self.w_axis_1.axis_selected in ifft_dict and (
+                    self.w_axis_2.axis_selected in fft_dict
+                    or self.w_axis_2.axis_selected in ifft_dict
+                ):
                     if self.w_axis_1.axis_selected in self.w_axis_1.axes_list:
                         self.w_axis_1.axes_list[
                             self.w_axis_1.axes_list.index(self.w_axis_1.axis_selected)
@@ -350,7 +353,10 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                         self.w_axis_1.axis_selected = ifft_dict[
                             self.w_axis_1.axis_selected
                         ]
-                elif self.w_axis_1.axis_selected in fft_dict:
+                elif self.w_axis_1.axis_selected in fft_dict and (
+                    self.w_axis_2.axis_selected in fft_dict
+                    or self.w_axis_2.axis_selected in ifft_dict
+                ):
                     if (
                         self.w_axis_1.axis_selected not in self.w_axis_1.axes_list
                         and fft_dict[self.w_axis_1.axis_selected]
@@ -363,7 +369,10 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                         ] = self.w_axis_1.axis_selected
                 # Make sure that all axes are reset to ifft
                 for i, axis in enumerate(self.w_axis_2.axes_list):
-                    if axis in ifft_dict:
+                    if axis in ifft_dict and (
+                        self.w_axis_2.axis_selected in fft_dict
+                        or self.w_axis_2.axis_selected in ifft_dict
+                    ):
                         self.w_axis_2.axes_list[i] = ifft_dict[axis]
             self.gen_slice_op(is_refresh=False)
         self.w_axis_1.set_unit()
